# -*- coding: UTF-8 -*-
###########################################################################
# Eole NG - 2007
# Copyright Pole de Competence Eole  (Ministere Education - Academie Dijon)
# Licence CeCill  cf /root/LicenceEole.txt
# eole@ac-dijon.fr
###########################################################################
"""
Fichier de configuration de l'application Zephir
"""
from os.path import join, dirname, abspath, isdir, isfile
from os import listdir
from creole.parsedico import parse_dico
import locale
from twisted.python import log
log.FileLogObserver.timeFormat = "%Y/%m/%d %H:%M:%S %Z"

conf = parse_dico()

charset = "UTF-8"

ADRESSE_LDAP = conf.get("adresse_ip_ldap", "localhost")
ADRESSE_ZEPHIR = conf.get("adresse_ip_eth0", "localhost")
BASE_LDAP = conf.get("ldap_base_dn", "o=gouv,c=fr")
LDAP_TLS = conf.get("ldap_tls", "non")
LDAP_CLIENT = conf.get('activer_client_ldap', 'local')
SLAPD_SSL = conf.get('ldap_ssl', 'non')
PORT_HTTP = "8090"
PORT_ZEPHIR = "7080"
PORT_WEB = 8070
NO_LOCAL_AGENTS = conf.get("no_local_agents", "non")

# Dans le cas d'un serveur LDAP local, on utilise tls
# seulement si il est obligatoire
if LDAP_CLIENT == "local" and SLAPD_SSL != "uniquement":
    LDAP_TLS = "non"

LOG_ACTIONS = False
if conf.get('log_actions', 'non') == 'oui':
    # Logguer les appels xmlrpc authentifiés dans les logs du backend
    LOG_ACTIONS = True

USE_THREADS = False
# mise en cache des configurations creole
if conf.get('zephir_use_threads', 'oui') == 'oui':
    # conservation en mémoire de la configuration creole des serveurs
    USE_THREADS = True
CREOLE_CACHE = False
# mise en cache des configurations creole
if conf.get('zephir_creole_cache', 'oui') == 'oui':
    # conservation en mémoire de la configuration creole des serveurs
    CREOLE_CACHE = True

# répertoire de base appli
ROOT_DIR = "/usr/share/zephir/"
PORT_AGENT = "8090"
AGENT_DIR = "agents"
CLIENT_UPDATE_HOST = "eoleng.ac-dijon.fr"
CLIENT_NG_URL = "/eoleng/eole-%s-security/%s"
SERVEURS_MAJ_CLIENTS = conf.get('serveur_maj_clients', [])

MAIL_ADRESSE = conf.get("passerelle_smtp", "localhost")
MAIL_TLS = conf.get("tls_smtp", "non")
MAIL_ACCOUNT = conf.get("system_mail_from","")

# répertoire de base des donnees backend
PATH_ZEPHIR = "/var/lib/zephir/"
PATH_TEMP = join("/tmp", "zephir_temp")
ADRESSE_SAUVEGARDE = join(PATH_ZEPHIR, 'user_prefs')

# certificats par défaut
cert_file = conf.get('server_cert', '') or '/etc/eole/ssl/eole.crt'
key_file = conf.get('server_key', '') or '/etc/eole/ssl/eole.key'

# manager prelude par défaut
PRELUDE_PORT = 4691

# détails des distributions gérées (nom_de_code, version_eole, maintenue)
DISTRIBS = {1:("Mdk 9.X", "1.X", False),
            2:("feisty", "2.0", False),
            3:("gutsy", "2.1", False),
            4:("hardy", "2.2", False),
            5:("lucid", "2.3", True),
            6:("precise", "2.4", True),
            7:("precise", "2.4.1", True)}

# version de creole en fonction de la version de distribution eole
CREOLE_VERSIONS = {1:'creole1',
                   2:'creole2',
                   3:'creole2',
                   4:'creole2',
                   5:'creole2',
                   6:'creole3',
                   7:'creole3',
                  }

# versions d'envole en fonction de la version eole
ENVOLE_VERSION = {7:"4"}

liste_modules = {}
PATH_DEF_MODULES = join(ROOT_DIR, 'default_modules')
# liste des modules eole, classés par version (la version 1 n'est plus gérée)
liste_modules = {
 1:['amon-1.5','sphynx-1.1','scribe-1.0','horus-1.0']
}
for num_dist in DISTRIBS.keys()[1:]:
    # recherche des modules Eole NG par défaut
    modules = []
    dist_dir = join(PATH_DEF_MODULES, str(num_dist))
    for mod_name in listdir(dist_dir):
        # on ignore les fichiers ~, .bak, etc...
        if isfile(join(dist_dir, mod_name)) and not \
                (mod_name.endswith('~') or \
                mod_name.endswith('.bak') or \
                mod_name.endswith('.swp')):
                # on vérifie qu'un répertoire de dictionnaires est bien présent pour ce module
                # if isdir(join(ROOT_DIR, 'dictionnaires', mod_name)):
                modules.append(mod_name)
    liste_modules[num_dist] = modules

# XXX : desactivation de modules pour Eole 2.3 - 5:('amon-2.3','sphynx-2.3','scribe-2.3','horus-2.3','zephir-2.3','preludemanager-2.3','zephirlogs-2.3','sentinelle-2.3','eclair-2.3','amonecole-2.3','seshat-2.3', 'eolebase-2.3'),

# liste des modules autorisés à migrer de plus d'une version
allowed_upgrades = {'horus':{2:[4], 4:[6,7], 5:[7]},
                    'scribe':{2:[4], 4:[6,7], 5:[7]},
                    'amon':{2:[4], 4:[6,7], 5:[7]},
                    'sphynx':{4:[6,7], 5:[7]},
                    'eolebase':{4:[6,7], 5:[7]},
                    'amonecole':{4:[7], 5:[7]},
                   }

# définition des migrations entre modules (adaptation de configuration nécessaire)
allowed_migrations = {1:[2,3,4], 4:[5,6,7], 5:[6,7]}

# liste des modules autorisés à être modifiés (édition de serveur)
allowed_mod_edits = {4:{'amon':['amonecole'],
                        'amonecole':['amon']},
                     5:{'amon':['amonecole'],
                        'amonecole':['amon']},
                     7:{'amon':['amonecole'],
                        'amonecole':['amon']}
                    }

# liste des verrous existants et de leurs dépendances
verrous = {'uucp':['Execution des tâches Zephir'],
           'sauvegarde':['Maj-Auto','Maj-Cd'],
           'maj':[],
           'configure':[],
           'reconfigure':[]}

# types  de fichiers à sauvegarder/envoyer
data_files = {0:('Tout', ['dicos','patchs','fichiers_perso','fichiers_zephir','zephir.eol','dico.eol','auth_keys','droits_zephir', 'droits_variante']),
              1:('Dictionnaires/templates/patchs/configuration/clés ssh', ['dicos','patchs','fichiers_perso','zephir.eol','auth_keys']),
              2:('Dictionnaires/templates/patchs', ['dicos','patchs','fichiers_perso']),
              3:('Fichiers divers/paquets', ['fichiers_zephir', 'droits_zephir', 'droits_variante']),
              4:('Configuration seulement (config.eol)', ['zephir.eol']),
              5:('Clés ssh seulement', ['auth_keys']),
             }

# libellés à affecter aux différents types de restrictions de ressources, table et champs correspondant (pour validation)
type_res_label =  {'rne':('numéro RNE', 'etablissements', 'rne'),
                   'groupe':('numéro de groupe', 'groupes_serveurs', 'id'),
                   'id_s':('numéro de serveur', 'serveurs', 'id'),
                   'id_var':('numéro de variante', 'variantes', 'id'),
                   'id_mod':('numéro de module', 'modules', 'id'),
                  }

# correspondance des caractères pour les xml des agents eole1
xml_table={'\\xc9':'\\xc3\\xa9',
           '\\xe9':'\\xc3\\xa9',
           '\\xc8':'\\xc3\\xa8',
           '\\xe8':'\\xc3\\xa8',
           '\\xf4':'\\xc3\\xb4',
           '\\xe0':'\\xc3\\xa0',
           }

# liste des variables creole donnant l'adresse d'un portail etablissement sur Scribe/Amonecole
var_portail = ['web_url', 'posh_url', 'scribe_envole_url', 'cas_domainname']
mod_portail = ['scribe', 'amonecole']

# temps entre chaque vérification des timeout (secondes)
SCAN_DELAY = 300
